@@ -3,6 +3,7 @@ context("writing backups")
 test_that("Backups are written", {
 			Bib <- read_bib(x = file.path(path.package("biblio"),
 							"LuebertPliscoff.bib"))
-			write_bib(x = Bib, file = "ex_bib.bib")
-			expect_true(file.exists("ex_bib.bib"))
+      File <- tempfile(fileext = ".bib")
+			write_bib(x = Bib, file = File)
+			expect_true(file.exists(File))
 		})
